@@ -36,7 +36,8 @@ __all__ = [
 		"imgbot_ignore",
 		"pkginfo_extra",
 		"exclude_files",
-		"pre_commit_exclude"
+		"pre_commit_exclude",
+		"desktopfile",
 		]
 
 
@@ -119,7 +120,6 @@ class exclude_files(ConfigVar):  # noqa
 		:header: "Value", "File(s) that will not be managed"
 		:widths: 20, 80
 
-		copy_pypi_2_github, ``.ci/copy_pypi_2_github.py``
 		lint_roller, ``lint_roller.sh``
 		stale_bot, ``.github/stale.yml``
 		auto_assign, ``.github/workflow/assign.yml`` and ``.github/auto_assign.yml``
@@ -136,7 +136,6 @@ class exclude_files(ConfigVar):  # noqa
 		tox, ``tox.ini``
 		test_requirements, :conf:`tests_dir` ``/requirements.txt``
 		dependabot, ``.dependabot/config.yml``
-		travis_deploy_conda, ``.ci/travis_deploy_conda.sh``
 		make_conda_recipe, ``make_conda_recipe.py``
 		bumpversion, ``.bumpversion.cfg``
 		issue_templates, ``.github/ISSUE_TEMPLATE/bug_report.md`` and ``.github/ISSUE_TEMPLATE/feature_request.md``
@@ -158,8 +157,27 @@ class pre_commit_exclude(ConfigVar):  # noqa
 	"""
 
 	dtype = str
-	default = "^$"
+	default: str = "^$"
 
 	@classmethod
-	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None) -> Any:
+	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None) -> Any:  # noqa: D102
 		return re.compile(super().validate(raw_config_vars)).pattern
+
+
+class desktopfile(ConfigVar):  # noqa
+	"""
+	A key value mapping of entries for a Linux ``.desktop`` file.
+
+	.. code-block:: yaml
+
+		desktopfile:
+		  Exec: wxIconSaver
+		  Icon: document-save
+
+	``Version``, ``Name`` and ``Comment`` are pre-populated from :conf:`version`, :conf:`modname` and :conf:`short_desc`.
+
+	.. versionadded:: 2020.11.15
+	"""
+
+	dtype = Dict[str, str]
+	default: Dict[str, str] = {}
